@@ -623,6 +623,11 @@ class TestRequestBasic:
             *arg1*
         """)
 
+    def test_show_fixtures_color_yes(self, testdir):
+        testdir.makepyfile("def test_this(): assert 1")
+        result = testdir.runpytest('--color=yes', '--fixtures')
+        assert '\x1b[32mtmpdir' in result.stdout.str()
+
     def test_newstyle_with_request(self, testdir):
         testdir.makepyfile("""
             import pytest
@@ -2483,6 +2488,44 @@ class TestShowFixtures:
         """)
 
 
+    def test_show_fixtures_different_files(self, testdir):
+        """
+        #833: --fixtures only shows fixtures from first file
+        """
+        testdir.makepyfile(test_a='''
+            import pytest
+
+            @pytest.fixture
+            def fix_a():
+                """Fixture A"""
+                pass
+
+            def test_a(fix_a):
+                pass
+        ''')
+        testdir.makepyfile(test_b='''
+            import pytest
+
+            @pytest.fixture
+            def fix_b():
+                """Fixture B"""
+                pass
+
+            def test_b(fix_b):
+                pass
+        ''')
+        result = testdir.runpytest("--fixtures")
+        result.stdout.fnmatch_lines("""
+            * fixtures defined from test_a *
+            fix_a
+                Fixture A
+
+            * fixtures defined from test_b *
+            fix_b
+                Fixture B
+        """)
+
+
 class TestContextManagerFixtureFuncs:
     def test_simple(self, testdir):
         testdir.makepyfile("""
