@@ -651,7 +651,8 @@ def lsof_check():
     pid = os.getpid()
     try:
         out = py.process.cmdexec("lsof -p %d" % pid)
-    except py.process.cmdexec.Error:
+    except (py.process.cmdexec.Error, UnicodeDecodeError):
+        # about UnicodeDecodeError, see note on conftest.py 
         pytest.skip("could not run 'lsof'")
     yield
     out2 = py.process.cmdexec("lsof -p %d" % pid)
@@ -1040,7 +1041,7 @@ def test_dontreadfrominput_has_encoding(testdir):
 
 
 def test_pickling_and_unpickling_enocded_file():
-    # See https://bitbucket.org/hpk42/pytest/pull-request/194
+    # See https://bitbucket.org/pytest-dev/pytest/pull-request/194
     # pickle.loads() raises infinite recursion if
     # EncodedFile.__getattr__ is not implemented properly
     ef = capture.EncodedFile(None, None)
