@@ -37,7 +37,7 @@ def test_recwarn_functional(testdir):
     assert tuple(res) == (2, 0, 0), res
 
 #
-# ============ test py.test.deprecated_call() ==============
+# ============ test pytest.deprecated_call() ==============
 #
 
 def dep(i):
@@ -53,29 +53,33 @@ def dep_explicit(i):
 
 def test_deprecated_call_raises():
     excinfo = pytest.raises(AssertionError,
-                   "py.test.deprecated_call(dep, 3)")
+                   "pytest.deprecated_call(dep, 3)")
     assert str(excinfo).find("did not produce") != -1
 
 def test_deprecated_call():
-    py.test.deprecated_call(dep, 0)
+    pytest.deprecated_call(dep, 0)
 
 def test_deprecated_call_ret():
-    ret = py.test.deprecated_call(dep, 0)
+    ret = pytest.deprecated_call(dep, 0)
     assert ret == 42
 
 def test_deprecated_call_preserves():
-    r = py.std.warnings.onceregistry.copy()
-    f = py.std.warnings.filters[:]
+    onceregistry = py.std.warnings.onceregistry.copy()
+    filters = py.std.warnings.filters[:]
+    warn = py.std.warnings.warn
+    warn_explicit = py.std.warnings.warn_explicit
     test_deprecated_call_raises()
     test_deprecated_call()
-    assert r == py.std.warnings.onceregistry
-    assert f == py.std.warnings.filters
+    assert onceregistry == py.std.warnings.onceregistry
+    assert filters == py.std.warnings.filters
+    assert warn is py.std.warnings.warn
+    assert warn_explicit is py.std.warnings.warn_explicit
 
 def test_deprecated_explicit_call_raises():
     pytest.raises(AssertionError,
-                   "py.test.deprecated_call(dep_explicit, 3)")
+                   "pytest.deprecated_call(dep_explicit, 3)")
 
 def test_deprecated_explicit_call():
-    py.test.deprecated_call(dep_explicit, 0)
-    py.test.deprecated_call(dep_explicit, 0)
+    pytest.deprecated_call(dep_explicit, 0)
+    pytest.deprecated_call(dep_explicit, 0)
 
