@@ -293,7 +293,7 @@ class TestExecutionForked(BaseFunctionalTests):
 
     def getrunner(self):
         # XXX re-arrange this test to live in pytest-xdist
-        xplugin = pytest.importorskip("xdist.plugin")
+        xplugin = pytest.importorskip("xdist.boxed")
         return xplugin.forked_run_report
 
     def test_suicide(self, testdir):
@@ -439,7 +439,7 @@ def test_exception_printing_skip():
         s = excinfo.exconly(tryshort=True)
         assert s.startswith("Skipped")
 
-def test_importorskip():
+def test_importorskip(monkeypatch):
     importorskip = pytest.importorskip
     def f():
         importorskip("asdlkj")
@@ -457,7 +457,7 @@ def test_importorskip():
         pytest.raises(SyntaxError, "pytest.importorskip('x=y')")
         mod = py.std.types.ModuleType("hello123")
         mod.__version__ = "1.3"
-        sys.modules["hello123"] = mod
+        monkeypatch.setitem(sys.modules, "hello123", mod)
         pytest.raises(pytest.skip.Exception, """
             pytest.importorskip("hello123", minversion="1.3.1")
         """)
@@ -471,6 +471,19 @@ def test_importorskip_imports_last_module_part():
     ospath = pytest.importorskip("os.path")
     assert os.path == ospath
 
+def test_importorskip_dev_module(monkeypatch):
+    try:
+        mod = py.std.types.ModuleType("mockmodule")
+        mod.__version__ = '0.13.0.dev-43290'
+        monkeypatch.setitem(sys.modules, 'mockmodule', mod)
+        mod2 = pytest.importorskip('mockmodule', minversion='0.12.0')
+        assert mod2 == mod
+        pytest.raises(pytest.skip.Exception, """
+            pytest.importorskip('mockmodule1', minversion='0.14.0')""")
+    except pytest.skip.Exception:
+        print(py.code.ExceptionInfo())
+        pytest.fail("spurious skip")
+
 
 def test_pytest_cmdline_main(testdir):
     p = testdir.makepyfile("""
